=== modified file 'NEWS'
--- NEWS	2008-06-06 18:04:45 +0000
+++ NEWS	2008-05-23 13:14:58 +0000
@@ -1,9 +1,5 @@
 0.95.0	UNRELEASED
 
- UI
-
-  * Added Refresh menu option with F5 keyboard shortcut (Russ Brown)
-
  BUG FIXES
 
   * Replace _() calls by _i18n() calls. (Vincent Ladeuil, #187283)

=== modified file '__init__.py'
--- __init__.py	2008-06-27 16:53:56 +0000
+++ __init__.py	2008-05-22 03:43:15 +0000
@@ -22,6 +22,7 @@
 gcommit           GTK+ commit dialog.
 gconflicts        GTK+ conflicts. 
 gdiff             Show differences in working tree in a GTK+ Window. 
+ghandle-patch     Display and optionally merge a merge directive or patch.
 ginit             Initialise a new branch.
 gmissing          GTK+ missing revisions dialog. 
 gpreferences      GTK+ preferences dialog. 
@@ -119,22 +120,21 @@
     return None
 
 
-def open_display():
-    pygtk = import_pygtk()
-    try:
-        import gtk
-    except RuntimeError, e:
-        if str(e) == "could not open display":
-            raise NoDisplayError
-    set_ui_factory()
-    return gtk
- 
-
 class GTKCommand(Command):
     """Abstract class providing GTK specific run commands."""
 
+    def open_display(self):
+        pygtk = import_pygtk()
+        try:
+            import gtk
+        except RuntimeError, e:
+            if str(e) == "could not open display":
+                raise NoDisplayError
+        set_ui_factory()
+        return gtk
+
     def run(self):
-        open_display()
+        self.open_display()
         dialog = self.get_gtk_dialog(os.path.abspath('.'))
         dialog.run()
 
@@ -168,7 +168,7 @@
 
     def run(self, location="."):
         (br, path) = branch.Branch.open_containing(location)
-        open_display()
+        self.open_display()
         from push import PushDialog
         dialog = PushDialog(br.repository, br.last_revision(), br)
         dialog.run()
@@ -286,7 +286,7 @@
     aliases = ["gblame", "gpraise"]
     
     def run(self, filename, all=False, plain=False, line='1', revision=None):
-        gtk = open_display()
+        gtk = self.open_display()
 
         try:
             line = int(line)
@@ -345,7 +345,7 @@
 
     def run(self, filename=None):
         import os
-        open_display()
+        self.open_display()
         from commit import CommitDialog
         from bzrlib.errors import (BzrCommandError,
                                    NotBranchError,
@@ -386,7 +386,7 @@
 
     def run(self, path='.', revision=None):
         import os
-        gtk = open_display()
+        gtk = self.open_display()
         from status import StatusDialog
         (wt, wt_path) = workingtree.WorkingTree.open_containing(path)
         
@@ -410,7 +410,7 @@
     """
     def run(self):
         (br, path) = branch.Branch.open_containing(".")
-        gtk = open_display()
+        gtk = self.open_display()
         from bzrlib.plugins.gtk.mergedirective import SendMergeDirectiveDialog
         from StringIO import StringIO
         dialog = SendMergeDirectiveDialog(br)
@@ -432,7 +432,7 @@
     """
     def run(self):
         (wt, path) = workingtree.WorkingTree.open_containing('.')
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.conflicts import ConflictsDialog
         dialog = ConflictsDialog(wt)
         dialog.run()
@@ -443,7 +443,7 @@
 
     """
     def run(self):
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.preferences import PreferencesWindow
         dialog = PreferencesWindow()
         dialog.run()
@@ -487,7 +487,7 @@
 
 class cmd_ginit(GTKCommand):
     def run(self):
-        open_display()
+        self.open_display()
         from initialize import InitDialog
         dialog = InitDialog(os.path.abspath(os.path.curdir))
         dialog.run()
@@ -497,7 +497,7 @@
     def run(self):
         br = branch.Branch.open_containing('.')[0]
         
-        gtk = open_display()
+        gtk = self.open_display()
         from tags import TagsWindow
         window = TagsWindow(br)
         window.show()
@@ -534,7 +534,7 @@
 
     def run(self):
         from notify import NotifyPopupMenu
-        gtk = open_display()
+        gtk = self.open_display()
         menu = NotifyPopupMenu()
         icon = gtk.status_icon_new_from_file(icon_path("bzr-icon-64.png"))
         icon.connect('popup-menu', menu.display)
@@ -692,6 +692,44 @@
 register_command(cmd_test_gtk)
 
 
+class cmd_ghandle_patch(GTKCommand):
+    """Display a patch or merge directive, possibly merging.
+
+    This is a helper, meant to be launched from other programs like browsers
+    or email clients.  Since these programs often do not allow parameters to
+    be provided, a "handle-patch" script is included.
+    """
+
+    takes_args = ['path']
+
+    def run(self, path):
+        try:
+            from bzrlib.plugins.gtk.diff import (DiffController,
+                                                 MergeDirectiveController)
+            if path == '-':
+                lines = sys.stdin.readlines()
+            else:
+                lines = open(path, 'rb').readlines()
+            lines = [l.replace('\r\n', '\n') for l in lines]
+            try:
+                directive = merge_directive.MergeDirective.from_lines(lines)
+            except errors.NotAMergeDirective:
+                controller = DiffController(path, lines)
+            else:
+                controller = MergeDirectiveController(path, directive)
+            window = controller.window
+            window.show()
+            gtk = self.open_display()
+            window.connect("destroy", gtk.main_quit)
+        except Exception, e:
+            from dialog import error_dialog
+            error_dialog('Error', str(e))
+            raise
+        gtk.main()
+
+
+register_command(cmd_ghandle_patch)
+
 
 import gettext
 gettext.install('olive-gtk')

=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-06-29 15:54:40 +0000
+++ branchview/linegraph.py	2008-05-04 18:16:01 +0000
@@ -12,8 +12,8 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tsort import merge_sort
 
-def linegraph(graph, start_revs, maxnum=None, broken_line_length=None,
-              graph_data=True, mainline_only=False):
+def linegraph(repository, start_revs, maxnum, broken_line_length = None,
+              graph_data = True, mainline_only = False):
     """Produce a directed graph of a bzr repository.
 
     Returns a tuple of (line_graph, revid_index, columns_len) where
@@ -43,6 +43,7 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
+    graph = repository.get_graph()
     graph_parents = {}
     ghosts = set()
     graph_children = {}

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-29 15:47:30 +0000
+++ branchview/treeview.py	2008-05-26 17:28:24 +0000
@@ -3,7 +3,7 @@
 
 """
 
-__copyright__ = "Copyright © 2005 Canonical Ltd."
+__copyright__ = "Copyright  2005 Canonical Ltd."
 __author__    = "Daniel Schierbeck <daniel.schierbeck@gmail.com>"
 
 import sys
@@ -285,8 +285,8 @@
         show_graph = self.graph_column.get_visible()
 
         self.branch.lock_read()
-        (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
-                                                        (self.start,) , # Sequence of start revisions
+        (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
+                                                        self.start,
                                                         self.maxnum, 
                                                         broken_line_length,
                                                         show_graph,

=== modified file 'bzr-gtk.applications'
--- bzr-gtk.applications	2008-06-27 16:55:09 +0000
+++ bzr-gtk.applications	2008-04-02 18:01:18 +0000
@@ -1,5 +1,5 @@
 bzr-gtk-patch
-	command=bzr-handle-patch
+	command="bzr handle-patch"
 	name=Bazaar
 	can_open_multiple_files=false
 	expects_uris=false

=== modified file 'commit.py'
--- commit.py	2008-06-07 09:00:24 +0000
+++ commit.py	2008-05-05 18:16:46 +0000
@@ -303,9 +303,6 @@
                             gtk.gdk.CONTROL_MASK, 0, self._on_accel_next)
         self.add_accel_group(group)
 
-        # ignore the escape key (avoid closing the window)
-        self.connect_object('close', self.emit_stop_by_name, 'close')
-
     def _construct_left_pane(self):
         self._left_pane_box = gtk.VBox(homogeneous=False, spacing=5)
         self._construct_file_list()

=== renamed file 'bzr-handle-patch' => 'handle-patch'
--- bzr-handle-patch	2008-06-27 16:53:56 +0000
+++ handle-patch	2008-02-23 06:39:14 +0000
@@ -1,39 +1,2 @@
-#!/usr/bin/python
-
-from bzrlib import errors, merge_directive
-from bzrlib.plugin import load_plugins
-from bzrlib.plugins.gtk import open_display
-load_plugins()
-
-import sys
-
-if len(sys.argv) < 2:
-	print "Usage: handle-patch <path>"
-	sys.exit(1)
-
-
-path = sys.argv[1]
-
-try:
-	from bzrlib.plugins.gtk.diff import (DiffController,
-										 MergeDirectiveController)
-	if path == '-':
-		lines = sys.stdin.readlines()
-	else:
-		lines = open(path, 'rb').readlines()
-	lines = [l.replace('\r\n', '\n') for l in lines]
-	try:
-		directive = merge_directive.MergeDirective.from_lines(lines)
-	except errors.NotAMergeDirective:
-		controller = DiffController(path, lines)
-	else:
-		controller = MergeDirectiveController(path, directive)
-	window = controller.window
-	window.show()
-	gtk = open_display()
-	window.connect("destroy", gtk.main_quit)
-except Exception, e:
-	from dialog import error_dialog
-	error_dialog('Error', str(e))
-	raise
-gtk.main()
+#!/bin/sh
+/home/abentley/bin/bzr ghandle-patch "$@"

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2008-06-23 08:05:19 +0000
+++ olive/__init__.py	2008-05-05 18:16:46 +0000
@@ -446,7 +446,7 @@
     @show_bzr_error
     def on_entry_history_revno_key_press_event(self, widget, event):
         """ Key pressed handler for the history entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to load that specific revision
             # Emulate being remote, so inventory should be used
             path = self.get_path()
@@ -461,7 +461,7 @@
     
     def on_entry_location_key_press_event(self, widget, event):
         """ Key pressed handler for the location entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to jump
             self.on_button_location_jump_clicked(widget)
     

=== modified file 'revisionview.py'
--- revisionview.py	2008-06-24 10:34:38 +0000
+++ revisionview.py	2008-06-04 20:36:54 +0000
@@ -38,11 +38,10 @@
 PAGE_SIGNATURE = 2
 PAGE_BUGS = 3
 
+webbrowser.register('sensible-browser', None, webbrowser.GenericBrowser('sensible-browser'), -1)
+webbrowser.register('xdg-open', None, webbrowser.GenericBrowser('xdg-open'), -1)
 
 def _open_link(widget, uri):
-    for cmd in ['sensible-browser', 'xdg-open']:
-        if webbrowser._iscommand(cmd):
-            webbrowser._tryorder.insert(0, '%s "%%s"' % cmd)
     webbrowser.open(uri)
 
 gtk.link_button_set_uri_hook(_open_link)

=== modified file 'setup.py'
--- setup.py	2008-06-27 16:53:56 +0000
+++ setup.py	2008-05-04 20:23:56 +0000
@@ -96,7 +96,7 @@
     maintainer_email = "jelmer@samba.org",
     description = "GTK+ Frontends for various Bazaar commands",
     license = "GNU GPL v2 or later",
-    scripts=['olive-gtk', 'bzr-handle-patch'],
+    scripts=['olive-gtk'],
     package_dir = {
         "bzrlib.plugins.gtk": ".",
         "bzrlib.plugins.gtk.viz": "viz", 

=== modified file 'tests/__init__.py'
--- tests/__init__.py	2008-06-29 15:54:40 +0000
+++ tests/__init__.py	2007-10-30 21:15:13 +0000
@@ -27,7 +27,6 @@
     testmod_names = [
         'test_commit',
         'test_diff',
-        'test_linegraph',
         'test_preferences',
         'test_history',
         ]

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2008-06-10 15:25:47 +0000
+++ tests/test_commit.py	2008-05-04 13:11:26 +0000
@@ -81,8 +81,8 @@
         rev_id1 = tree.commit('one')
         tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
         rev_id2 = tree2.commit('two')
+        rev_id3 = tree2.commit('three')
         tree3 = tree2.bzrdir.sprout('tree3').open_workingtree()
-        rev_id3 = tree2.commit('three')
         rev_id4 = tree3.commit('four')
         rev_id5 = tree3.commit('five')
         tree.merge_from_branch(tree2.branch)
@@ -985,7 +985,8 @@
                          ], bencode.bdecode(file_info))
 
     def test_commit_unicode_messages(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         tree.branch.get_config().set_user_option('per_file_commits', 'true')

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2008-06-09 15:59:13 +0000
+++ tests/test_diff.py	2008-05-22 19:08:04 +0000
@@ -69,7 +69,8 @@
 class TestDiffView(tests.TestCaseWithTransport):
 
     def test_unicode(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         self.build_tree([u'tree/\u03a9'])

=== removed file 'tests/test_linegraph.py'
--- tests/test_linegraph.py	2008-06-29 15:54:40 +0000
+++ tests/test_linegraph.py	1970-01-01 00:00:00 +0000
@@ -1,45 +0,0 @@
-# Copyright (C) 2008 Jelmer Vernooij <jelmer@samba.org>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the linegraph functionality."""
-
-import os
-
-import gtk
-
-from bzrlib import (
-	graph,
-    tests,
-    )
-from bzrlib.util import bencode
-
-from bzrlib.plugins.gtk.branchview.linegraph import linegraph
-
-
-class TestLinegraph(tests.TestCase):
-	def get_graph(self, dict):
-		return graph.Graph(graph.DictParentsProvider(dict))
-
-	def test_simple(self):
-		lg = linegraph(self.get_graph({"A": ("B", "C"), "B": ()}), ["A"])
-		self.assertEquals(lg,  
-            ([
-               ['A', (0, 0), [(0, 0, 0)], ['B'], [], (2,)],
-               ['B', (0, 0), [], (), ['A'], (1,)]
-             ],
-             {'A': 0, 'B': 1},
-             1))
-

=== modified file 'ui.py'
--- ui.py	2008-06-20 03:36:30 +0000
+++ ui.py	2008-05-01 22:24:50 +0000
@@ -58,7 +58,7 @@
     def update(self, msg=None, current=None, total=None):
         if msg is not None:
             self.set_text(msg)
-        if None not in (current, total) and total > 0:
+        if None not in (current, total):
             self.set_fraction(1.0 * current / total)
         while gtk.events_pending():
             gtk.main_iteration()

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2008-06-06 17:46:26 +0000
+++ viz/branchwin.py	2008-04-25 20:27:21 +0000
@@ -66,7 +66,6 @@
 
         gtk.accel_map_add_entry("<viz>/Go/Next Revision", gtk.keysyms.Up, gtk.gdk.MOD1_MASK)
         gtk.accel_map_add_entry("<viz>/Go/Previous Revision", gtk.keysyms.Down, gtk.gdk.MOD1_MASK)
-        gtk.accel_map_add_entry("<viz>/View/Refresh", gtk.keysyms.F5, 0)
 
         self.accel_group = gtk.AccelGroup()
         self.add_accel_group(self.accel_group)
@@ -85,12 +84,6 @@
         self.next_rev_action.connect("activate", self._fwd_clicked_cb)
         self.next_rev_action.connect_accelerator()
 
-        self.refresh_action = gtk.Action("refresh", "_Refresh", "Refresh view", gtk.STOCK_REFRESH)
-        self.refresh_action.set_accel_path("<viz>/View/Refresh")
-        self.refresh_action.set_accel_group(self.accel_group)
-        self.refresh_action.connect("activate", self._refresh_clicked)
-        self.refresh_action.connect_accelerator()
-
         self.construct()
 
     def set_revision(self, revid):
@@ -151,12 +144,6 @@
         view_menuitem = gtk.MenuItem("_View")
         view_menuitem.set_submenu(view_menu)
 
-        view_menu_refresh = self.refresh_action.create_menu_item()
-        view_menu_refresh.connect('activate', self._refresh_clicked)
-
-        view_menu.add(view_menu_refresh)
-        view_menu.add(gtk.SeparatorMenuItem())
-
         view_menu_toolbar = gtk.CheckMenuItem("Show Toolbar")
         view_menu_toolbar.set_active(True)
         view_menu_toolbar.connect('toggled', self._toolbar_visibility_changed)

